@@ -22,7 +22,7 @@
 
 #include <libgnomevfsmm/init.h>
 #include <libgnomevfsmm/wrap_init.h>
-#include <gtkmm/main.h>
+#include <glibmm/init.h>
 #include <libgnomevfsmmconfig.h> //For LIBGNOMEVFSMM_VERSION
 #include <libgnomevfs/gnome-vfs-init.h>
 
@@ -34,7 +34,7 @@ namespace Vfs
 
 void init()
 {
-  Gtk::Main::init_gtkmm_internals(); //Sets up the g type system and the Glib::wrap() table.
+  Glib::init(); //Sets up the g type system and the Glib::wrap() table.
   wrap_init(); //Tells the Glib::wrap() table about the libgnomecanvasmm classes.
   gnome_vfs_init();
 }
