@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "gtkmm_generate_extra_defs/generate_extra_defs.h"
+#include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <libgnomevfs/gnome-vfs.h>
 //#include <libgnomevfs/gnome-vfs-metadata.h>
 #include <libgnomevfs/gnome-vfs-mime-monitor.h>
